Learn R Programming

GMSimpute (version 0.0.1.0)

tcga.bc.full: A subset of mass spectrum metabolomics data for TCGA breast cancer study without missing peaks.

Description

A subset of mass spectrum metabolomics data for TCGA breast cancer study without missing peaks.

Usage

tcga.bc.full

Arguments

Format

A data frame of 100 rows and 30 columns without missing value (NA).